<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Registers your tab in the quiz settings page
 *
 * @since 1.0.0
 * @return void
 */
function qsm_addon_advanced_timer_register_quiz_settings_tabs() {
  global $mlwQuizMasterNext;
  if ( ! is_null( $mlwQuizMasterNext ) && ! is_null( $mlwQuizMasterNext->pluginHelper ) && method_exists( $mlwQuizMasterNext->pluginHelper, 'register_quiz_settings_tabs' ) ) {
    $mlwQuizMasterNext->pluginHelper->register_quiz_settings_tabs('Advanced Timer', 'qsm_addon_advanced_timer_quiz_settings_tabs_content' );
  }
}

/**
 * Generates the content for your quiz settings tab
 *
 * @since 1.0.0
 * @return void
 */
function qsm_addon_advanced_timer_quiz_settings_tabs_content() {

  global $mlwQuizMasterNext;
  $date_now = date("d-m-Y");
  $settings_data	 = get_option('qsm_addon_advanced_timer_settings', '');
  $license		 = isset( $settings_data['license_key'] ) ? trim( $settings_data['license_key'] ) : '';
  $license_status	 = isset( $settings_data['license_status'] ) ? $settings_data['license_status'] : '';
  //Enqueue admin script
  wp_enqueue_script( 'qsm_advanced_timer_admin', plugins_url( '../js/admin.js' , __FILE__ ), array( 'jquery' ) );
  if( '' != $license && 'valid' == $license_status ) {
    if ( version_compare( $mlwQuizMasterNext->version, '8.1.6', '>' ) && (isset($settings_data['expiry_date']) && "" != $settings_data['expiry_date']) && (isset($settings_data['last_validate']) && "" != $settings_data['last_validate']) && strtotime($date_now) > strtotime($settings_data['expiry_date']) && strtotime($date_now) >= strtotime($settings_data['last_validate']) ) { 
      $item_url = 'https://quizandsurveymaster.com/checkout/?edd_license_key='.$license.'&download_id='.QSM_ADVANCED_TIMER_ITEM;
      $target_text =  __('License Key Expired. ', 'qsm-advanced-timer');
      $target_link = sprintf( $target_text.'<a style="font-weight: 500;" href="%s" target="_blank">%s</a>', esc_url( $item_url ), __( 'Click here to renew', 'qsm-advanced-timer' ) );
      $mlwQuizMasterNext->alertManager->newAlert( $target_link, 'error' );
    }
  //If nonce is set and correct, save the form
  if ( isset( $_POST["advanced_timer_integration_nonce"] ) && wp_verify_nonce( $_POST['advanced_timer_integration_nonce'], 'advanced_timer_integration') ) {
      
    $at_data = array(
      'start_timer_page' => sanitize_text_field( $_POST["start_timer_page"] ),
      'show_stop_timer' => sanitize_text_field( $_POST["show_stop_timer"] ),
      'timer_design' => sanitize_text_field( $_POST["timer_design"] ),
      'show_warning' => sanitize_text_field( $_POST["show_warning"] ),
      'timer_continues_after_closing' => sanitize_text_field( $_POST["timer_continues_after_closing"] ),
      'timer_continues_per_page' => sanitize_text_field( $_POST["timer_continues_per_page"] ),
    );
    $mlwQuizMasterNext->pluginHelper->update_quiz_setting( "advanced_timer_integration_settings", $at_data );
    $mlwQuizMasterNext->alertManager->newAlert(__( 'Your settings has been saved successfully!', 'qsm-advanced-timer' ), 'success' );
  }

  // Load the settings
  $at_data = $mlwQuizMasterNext->pluginHelper->get_quiz_setting( "advanced_timer_integration_settings" );
  $at_defaults = array(
    'start_timer_page' => '1',
    'show_stop_timer' => 'no',
    'timer_design' => 'right_bottom_timer',    
    'show_warning' => 'no',
    'timer_continues_after_closing' => 'no',
    'timer_continues_per_page' => 'no'   
  );
  $at_data = wp_parse_args( $at_data, $at_defaults );  
  ?>
<style type="text/css">
    .et-preview-main-wrapper{
        display: inline-block;
        vertical-align: top;
        margin-left: 0px;        
        margin-top: 20px;
    }
    .et-preview-main-wrapper .show_preview_timer{
        border: 1px solid #d8d6ecfa;
        padding: 15px;
        width: 200px;
        height: 200px;
        text-align: center;
        position: relative;
    }
    .et-preview-main-wrapper .show_preview_timer img{
        position: absolute;
        top: 0;
        bottom: 0;
        left: 0;
        right: 0;
        margin: auto;
    }
    .at-preview-text{
        margin: 0;
        font-size: 14px;
        color: #bcbbc9fa;
        margin-bottom: 5px;
    }
</style>
  <div class="qsm-alerts">
		<?php $mlwQuizMasterNext->alertManager->showAlerts(); ?>
	</div>
  <div id="tabs-mailchimp-integration" class="mlw_tab_content">
    <h2><?php _e('Advanced Timer Settings', 'qsm-advanced-timer'); ?></h2>
    <form action="" method="post">
      <button class="button-primary"><?php _e( 'Save Settings', 'qsm-advanced-timer' ); ?></button>
      <table class="form-table" style="width: 100%;">
        <tr valign="top">
          <th scope="row" colspan="2"><label for="doc">
            <?php 
            $start_anchor = '<a href="https://quizandsurveymaster.com/how-to-set-a-timer-on-individual-quiz-pages-in-qsm/" target="_blank">';
            $end_anchor = '</a>';
            echo sprintf(__('%1$sLearn More%2$s about configuring Advanced Timer for individual pages.','qsm-advanced-timer'),$start_anchor,$end_anchor);
            ?>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="allow_logged_in_user_multiple"><?php _e( 'Start timer automatically on page', 'qsm-advanced-timer' ); ?> <br/> <b style="color: red;"><?php _e( 'Note:', 'qsm-advanced-timer' ); ?></b><?php _e( 'This option will work only if pagination is enabled', 'qsm-advanced-timer' ); ?></label></th>
            <td>
                <input type="text" id="start_timer_page" name="start_timer_page" value='<?php echo $at_data["start_timer_page"]; ?>' />
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="payment_message"><?php _e( 'Show Stop timer button at the end of page?', 'qsm-advanced-timer' ); ?></label></th>
            <td>
                <input type="radio" name="show_stop_timer" value='yes' <?php checked($at_data['show_stop_timer'], 'yes') ?> /><?php _e( 'Yes', 'qsm-advanced-timer' );?><br>
                <input type="radio" name="show_stop_timer" value='no' <?php checked($at_data['show_stop_timer'], 'no') ?>/><?php _e( 'No', 'qsm-advanced-timer' ); ?><br>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="payment_message"><?php _e( 'Timer Design', 'qsm-advanced-timer' ); ?></label></th>
            <td id="timer_design">
                <input type="radio" name="timer_design" value='right_bottom_timer' <?php checked($at_data['timer_design'], 'right_bottom_timer') ?> /><?php _e( 'Standard Timer', 'qsm-advanced-timer' ); ?>   &nbsp;&nbsp;&nbsp;&nbsp;
                <input type="radio" name="timer_design" value='big_timer' <?php checked($at_data['timer_design'], 'big_timer') ?>/><?php _e( 'Timer with progress bar', 'qsm-advanced-timer' ); ?>  <br/>
                <div class="et-preview-main-wrapper">
                    <h2 class="at-preview-text"><?php _e( 'Preview', 'qsm-advanced-timer' ); ?></h2>
                    <div class="show_preview_timer">
                        <img style="display: none" id="right_bottom_timer" src="<?php echo QSM_ADVANCED_TIMER_PLUGIN_URL . '/img/right_side_timer.png'; ?>"/>
                        <img style="display: none" id="big_timer" src="<?php echo QSM_ADVANCED_TIMER_PLUGIN_URL . '/img/big_timer.png'; ?>"/>
                    </div>
                </div>                
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="payment_message"><?php _e( 'Show warning when timer is 90% completed?', 'qsm-advanced-timer' ); ?></label></th>
            <td>
                <input type="radio" name="show_warning" value='yes' <?php checked($at_data['show_warning'], 'yes') ?> /><?php _e( 'Yes', 'qsm-advanced-timer' ); ?><br>
                <input type="radio" name="show_warning" value='no' <?php checked($at_data['show_warning'], 'no') ?>/><?php _e( 'No', 'qsm-advanced-timer' ); ?><br>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="timer_continues_after_closing"><?php _e( 'Timer continues after closing browser window/tab', 'qsm-advanced-timer' ); ?></label></th>
            <td>
                <input type="radio" name="timer_continues_after_closing" value='yes' <?php checked($at_data['timer_continues_after_closing'], 'yes') ?> /><?php _e( 'Yes', 'qsm-advanced-timer' ); ?><br>
                <input type="radio" name="timer_continues_after_closing" value='no' <?php checked($at_data['timer_continues_after_closing'], 'no') ?>/><?php _e( 'No', 'qsm-advanced-timer' ); ?><br>
            </td>
        </tr>
        <tr valign="top">
            <th scope="row"><label for="timer_continues_per_page"><?php _e( 'Per page Timer continues after closing browser window/tab', 'qsm-advanced-timer' ); ?></label></th>
            <td>
                <input type="radio" name="timer_continues_per_page" value='yes' <?php checked($at_data['timer_continues_per_page'], 'yes') ?> /><?php _e( 'Yes', 'qsm-advanced-timer' ); ?><br>
                <input type="radio" name="timer_continues_per_page" value='no' <?php checked($at_data['timer_continues_per_page'], 'no') ?>/><?php _e( 'No', 'qsm-advanced-timer' ); ?><br>
            </td>
        </tr>
      </table>
      <?php wp_nonce_field('advanced_timer_integration','advanced_timer_integration_nonce'); ?>
      <button class="button-primary"><?php _e( 'Save Settings', 'qsm-advanced-timer' );  ?></button>
    </form>
  </div>
  <?php
  }else{
		$params		 = array(
			'please_wait'    => __('Please Wait...', 'qsm-advanced-timer'),
			'license_msg'    => __('License Key Required.', 'qsm-advanced-timer'),
		);
		wp_localize_script( 'qsm_advanced_timer_admin', 'qsm_advanced_t_obj', $params );
		$mlwQuizMasterNext->alertManager->showAlerts();?>
		<div class="license_form_parent">
			<div id="license_message" style="display: none;" class="error below-h2"><p><strong class="qsm_advanced_t_validate_message"></strong></div>
			<h4><strong><?php esc_html_e( 'Please validate your licence key. ', 'qsm-advanced-timer' ); ?></strong></h4>
			<div class="qsm_advanced_t_validate_parent">
				<form class="rq_validata-license" method="POST">
					<input type="text" placeholder="<?php echo esc_html("Enter your license key"); ?>" class="qsm_advanced_t_validate_input" name="qsm_advanced_t_validate_input" />
					<input type="submit" name="qsm_advanced_t_validate_button" class="qsm_advanced_t_validate_button button button-primary" />
				</form>
			</div>
		</div>
		<?php
	}
}
?>
